<?php
/**
 * Radiant cf7 Addon
 *
 * @package Radiantthemes
 */

namespace RadiantthemesAddons\Widgets;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Widget_Base;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor Contact Form 7 widget.
 *
 * Contact form 7 displaying in custom styles.
 *
 * @since 1.0.0
 */
class Radiantthemes_Style_Cf7 extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'radiant-cf7';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Contact Form 7', 'radiantthemes-addons' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-envelope';
	}

	/**
	 * Requires css files.
	 *
	 * @return array
	 */
	public function get_style_depends() {
		return [
			'radiantthemes-addons-custom',
		];
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'radiant-widgets-category' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'section_contact_form',
			[
				'label' => esc_html__( 'Contact Form', 'radiantthemes-addons' ),
			]
		);
		$this->add_control(
			'radiant_cf7_style',
			[
				'label'       => esc_html__( 'Select Contact Form 7 Style', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT2,
				'options'     => [
					'one' => esc_html__( 'Style One (Simple)', 'radiantthemes-addons' ),
				],
				'default'     => 'one',
			]
		);

		$cf7 = get_posts( 'post_type="wpcf7_contact_form"&numberposts=-1' );

		$contact_forms = array();
		if ( $cf7 ) {
			foreach ( $cf7 as $cform ) {
				(int) $contact_forms[ $cform->ID ] = $cform->post_title;
			}
		} else {
			(int) $contact_forms['0'] = esc_html__( 'No contact forms found', 'radiantthemes-addons' );
		}

		$this->add_control(
			'rt_select_ct_form',
			[
				'label'       => esc_html__( 'Select contact form', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT2,
				'options'     => $contact_forms,
				'description' => esc_html__( 'Choose previously created contact form from the drop down list.', 'radiantthemes-addons' ),
			]
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'rt_section_cf7_btn_design',
			[
				'label' => esc_html__( 'Submit Button Design', 'radiantthemes-addons' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'radiant_cf7_btn_gradient_bg_add',
			[
				'label'        => esc_html__( 'Add Gradient Background?', 'radiantthemes-addons' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'radiantthemes-addons' ),
				'label_off'    => esc_html__( 'No', 'radiantthemes-addons' ),
				'return_value' => 'yes',
				'default'      => 'yes',
				'description'  => esc_html__( 'Please Note: If selected, please do not use any background image or direct backgrund color.', 'radiantthemes-addons' ),
			]
		);

		$this->add_control(
			'radiant_cf7_btn_gradient_bg_type',
			[
				'label'       => esc_html__( 'Gradient Background Type', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT2,
				'options'     => [
					'to bottom'       => esc_html__( 'To Bottom', 'radiantthemes-addons' ),
					'to top'          => esc_html__( 'To Top', 'radiantthemes-addons' ),
					'to right'        => esc_html__( 'To Right', 'radiantthemes-addons' ),
					'to left'         => esc_html__( 'To Left', 'radiantthemes-addons' ),
					'to top left'     => esc_html__( 'To Top Left', 'radiantthemes-addons' ),
					'to bottom left'  => esc_html__( 'To Bottom Left', 'radiantthemes-addons' ),
					'to top right'    => esc_html__( 'To Top Right', 'radiantthemes-addons' ),
					'to bottom right' => esc_html__( 'To Bottom Right', 'radiantthemes-addons' ),
				],
				'condition'   => [
					'radiant_cf7_btn_gradient_bg_add' => 'yes',
				],
				'description' => esc_html__( 'Select backgroud type.', 'radiantthemes-addons' ),
			]
		);

		$this->add_control(
			'radiant_cf7_btn_gradient_bg_color_one',
			[
				'label'     => esc_html__( 'Background Color (One)', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => [
					'radiant_cf7_btn_gradient_bg_add' => 'yes',
				],
			]
		);

		$this->add_control(
			'radiant_cf7_btn_gradient_bg_color_two',
			[
				'label'     => esc_html__( 'Background Color (Two)', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=submit]' => 'background: linear-gradient({{radiant_cf7_btn_gradient_bg_type.VALUE}}, {{radiant_cf7_btn_gradient_bg_color_one.VALUE}} 0%, {{VALUE}} 100%)',
				],
				'condition' => [
					'radiant_cf7_btn_gradient_bg_add' => 'yes',
				],
			]
		);
		$this->add_control(
			'radiant_cf7_btn_gradient_bg_add_hover',
			[
				'label'        => esc_html__( 'Add Gradient Background Hover?', 'radiantthemes-addons' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'radiantthemes-addons' ),
				'label_off'    => esc_html__( 'No', 'radiantthemes-addons' ),
				'return_value' => 'yes',
				'default'      => 'yes',
				'description'  => esc_html__( 'Please Note: If selected, please do not use any background image or direct backgrund hover color.', 'radiantthemes-addons' ),
			]
		);

		$this->add_control(
			'radiant_cf7_btn_gradient_bg_type_hover',
			[
				'label'       => esc_html__( 'Gradient Background Type', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT2,
				'options'     => [
					'to bottom'       => esc_html__( 'To Bottom', 'radiantthemes-addons' ),
					'to top'          => esc_html__( 'To Top', 'radiantthemes-addons' ),
					'to right'        => esc_html__( 'To Right', 'radiantthemes-addons' ),
					'to left'         => esc_html__( 'To Left', 'radiantthemes-addons' ),
					'to top left'     => esc_html__( 'To Top Left', 'radiantthemes-addons' ),
					'to bottom left'  => esc_html__( 'To Bottom Left', 'radiantthemes-addons' ),
					'to top right'    => esc_html__( 'To Top Right', 'radiantthemes-addons' ),
					'to bottom right' => esc_html__( 'To Bottom Right', 'radiantthemes-addons' ),
				],
				'condition'   => [
					'radiant_cf7_btn_gradient_bg_add_hover' => 'yes',
				],
				'description' => esc_html__( 'Select backgroud type.', 'radiantthemes-addons' ),
			]
		);

		$this->add_control(
			'radiant_cf7_btn_gradient_bg_color_one_hover',
			[
				'label'     => esc_html__( 'Background Color (One)', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => [
					'radiant_cf7_btn_gradient_bg_add_hover' => 'yes',
				],
			]
		);

		$this->add_control(
			'radiant_cf7_btn_gradient_bg_color_two_hover',
			[
				'label'     => esc_html__( 'Background Color (Two)', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=submit]:hover' => 'background: linear-gradient({{radiant_cf7_btn_gradient_bg_type_hover.VALUE}}, {{radiant_cf7_btn_gradient_bg_color_one_hover.VALUE}} 0%, {{VALUE}} 100%)',
				],
				'condition' => [
					'radiant_cf7_btn_gradient_bg_add_hover' => 'yes',
				],
			]
		);
		$this->add_control(
			'rt_submit_background_color',
			[
				'label'     => esc_html__( 'Submit Button Background Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=submit]' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'radiant_cf7_btn_gradient_bg_add!' => 'yes',
				],
			]
		);
		$this->add_control(
			'rt_submit_hover_color',
			[
				'label'     => esc_html__( 'Submit Button Background Hover Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=submit]:hover' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'radiant_cf7_btn_gradient_bg_add_hover!' => 'yes',
				],
			]
		);
		$this->add_control(
			'rt_submit_text_color',
			[
				'label'     => esc_html__( 'Submit Button Text Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=submit]' => 'color: {{VALUE}}',
				],
				'default'   => '#ffffff',
			]
		);
		$this->add_control(
			'rt_submit_text_hover_color',
			[
				'label'     => esc_html__( 'Submit Button Text Hover Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=submit]:hover' => 'color: {{VALUE}}',
				],
				'default'   => '#ffffff',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'border',
				'label'    => esc_html__( 'Border', 'radiantthemes-addons' ),
				'selector' => '{{WRAPPER}} .radiant-contact-form .form-row input[type=submit]',
			]
		);
		$this->add_control(
			'radiant_border_radius_submit_btn',
			[
				'label'      => esc_html__( 'Border Radius', 'radiantthemes-addons' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=submit]' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'radiant_padding_submit_btn',
			[
				'label'      => esc_html__( 'Padding', 'radiantthemes-addons' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=submit]' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'rt_section_cf7_form_row_settings',
			[
				'label' => esc_html__( 'Form Row Settings', 'radiantthemes-addons' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'rt_margin_form_row',
			[
				'label'      => esc_html__( 'Margin', 'radiantthemes-addons' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .radiant-contact-form .form-row' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'rt_section_cf7_input_box_settings',
			[
				'label' => esc_html__( 'Input Box Settings', 'radiantthemes-addons' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'radiant_background_color_input',
			[
				'label'     => esc_html__( 'Background Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=text]'     => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=email]'    => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=url]'      => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=tel]'      => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=number]'   => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=password]' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=date]'     => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=time]'     => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=file]'     => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row select'               => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row textarea'             => 'background-color: {{VALUE}}',
				],
				'default'   => '#ffffff',
			]
		);
		$this->add_control(
			'radiant_font_color_input',
			[
				'label'     => esc_html__( 'Font Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=text]'     => 'color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=email]'    => 'color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=url]'      => 'color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=tel]'      => 'color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=number]'   => 'color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=password]' => 'color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=date]'     => 'color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=time]'     => 'color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=file]'     => 'color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row select'               => 'color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row textarea'             => 'color: {{VALUE}}',
				],
				'default'   => '#252525',
			]
		);
		$this->add_control(
			'radiant_border_radius_input',
			[
				'label'      => esc_html__( 'Border Radius', 'radiantthemes-addons' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=text]'     => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=email]'    => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=url]'      => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=tel]'      => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=number]'   => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=password]' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=date]'     => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=time]'     => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=file]'     => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .radiant-contact-form .form-row select'               => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .radiant-contact-form .form-row textarea'             => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'radiant_padding_input',
			[
				'label'      => esc_html__( 'Padding', 'radiantthemes-addons' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=text]'     => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=email]'    => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=url]'      => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=tel]'      => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=number]'   => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=password]' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=date]'     => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=time]'     => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=file]'     => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .radiant-contact-form .form-row select'               => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .radiant-contact-form .form-row textarea'             => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'radiant_border_input',
				'label'    => esc_html__( 'Border', 'radiantthemes-addons' ),
				'selector' => '{{WRAPPER}} .radiant-contact-form .form-row input[type=text], {{WRAPPER}} .radiant-contact-form .form-row input[type=email], {{WRAPPER}} .radiant-contact-form .form-row input[type=url], {{WRAPPER}} .radiant-contact-form .form-row input[type=tel], {{WRAPPER}} .radiant-contact-form .form-row input[type=number], {{WRAPPER}} .radiant-contact-form .form-row input[type=password], {{WRAPPER}} .radiant-contact-form .form-row input[type=date], {{WRAPPER}} .radiant-contact-form .form-row input[type=time], {{WRAPPER}} .radiant-contact-form .form-row input[type=file], {{WRAPPER}} .radiant-contact-form .form-row select, {{WRAPPER}} .radiant-contact-form .form-row textarea',
			]
		);
		$this->add_control(
			'radiant_font_focus_color_input',
			[
				'label'       => esc_html__( 'Font Color Focus', 'radiantthemes-addons' ),
				'type'        => Controls_Manager::COLOR,
				'description' => esc_html__( 'Form here you can change the Focus Font Color For Input Fields.', 'radiantthemes-addons' ),
				'selectors'   => [
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=text]:focus'     => 'color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=email]:focus'    => 'color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=url]:focus'      => 'color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=tel]:focus'      => 'color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=number]:focus'   => 'color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=password]:focus' => 'color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=date]:focus'     => 'color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=time]:focus'     => 'color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=file]:focus'     => 'color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row select:focus'               => 'color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row textarea:focus'             => 'color: {{VALUE}}',
				],
				'default'     => '#252525',
			]
		);
		$this->add_control(
			'radiant_background_focus_color_input',
			[
				'label'       => esc_html__( 'Background Color Focus', 'radiantthemes-addons' ),
				'type'        => Controls_Manager::COLOR,
				'description' => esc_html__( 'Form here you can change the Focus Background Color For Input Fields.', 'radiantthemes-addons' ),
				'selectors'   => [
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=text]:focus'     => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=email]:focus'    => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=url]:focus'      => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=tel]:focus'      => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=number]:focus'   => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=password]:focus' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=date]:focus'     => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=time]:focus'     => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row input[type=file]:focus'     => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row select:focus'               => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .radiant-contact-form .form-row textarea:focus'             => 'background-color: {{VALUE}}',
				],
				'default'     => '#252525',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'radiant_border_input_focus',
				'label'    => esc_html__( 'Border Focus', 'radiantthemes-addons' ),
				'selector' => '{{WRAPPER}} .radiant-contact-form .form-row input[type=text]:focus, {{WRAPPER}} .radiant-contact-form .form-row input[type=email]:focus, {{WRAPPER}} .radiant-contact-form .form-row input[type=url]:focus, {{WRAPPER}} .radiant-contact-form .form-row input[type=tel]:focus, {{WRAPPER}} .radiant-contact-form .form-row input[type=number]:focus, {{WRAPPER}} .radiant-contact-form .form-row input[type=password]:focus, {{WRAPPER}} .radiant-contact-form .form-row input[type=date]:focus, {{WRAPPER}} .radiant-contact-form .form-row input[type=time]:focus, {{WRAPPER}} .radiant-contact-form .form-row input[type=file]:focus, {{WRAPPER}} .radiant-contact-form .form-row select:focus, {{WRAPPER}} .radiant-contact-form .form-row textarea:focus',
			]
		);
		$this->add_control(
			'radiant_width_input',
			[
				'label'      => esc_html__( 'Textarea Height', 'radiantthemes-addons' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range'      => [
					'px' => [
						'min'  => 0,
						'max'  => 1000,
						'step' => 1,
					],
				],
				'selectors'  => [
					'{{WRAPPER}} .radiant-contact-form .form-row textarea' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		$output = '<div class="radiant-contact-form element-' . esc_attr( $settings['radiant_cf7_style'] ) . '">';
		$output .= do_shortcode( '[contact-form-7 id="' . $settings['rt_select_ct_form'] . '"]' );
		$output .= '<div class="clearfix"></div>';
		$output .= '</div>';

		echo $output;
	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function _content_template() {

	}
}
