<?php
/**
 * Custom Button Style Addon
 *
 * @package Radiantthemes
 */

namespace RadiantthemesAddons\Widgets;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Widget_Base;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor Custom Button widget.
 *
 * Elementor widget that displays a custom button.
 *
 * @since 1.0.0
 */
class Radiantthemes_Style_Custom_Button extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'radiant-custom-button';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Custom Button', 'radiantthemes-addons' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-button';
	}

	/**
	 * Requires css files.
	 *
	 * @return array
	 */
	public function get_style_depends() {
		return [
			'radiantthemes-addons-custom',
		];
	}

	/**
	 * Requires js files.
	 *
	 * @return array
	 */
	public function get_script_depends() {
		return [
			'',
		];
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'radiant-widgets-category' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'section_custom_button',
			[
				'label' => esc_html__( 'Custom Button', 'radiantthemes-addons' ),
			]
		);

		$this->add_control(
			'radiant_custom_btn_style',
			[
				'label'       => esc_html__( 'Button Style', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT2,
				'options'     => [
					'one'   => esc_html__( 'Style One', 'radiantthemes-addons' ),
					'two'   => esc_html__( 'Style Two', 'radiantthemes-addons' ),
					
				],
				'default'     => 'one',
			]
		);

		$this->add_control(
			'radiant_custom_btn_title',
			[
				'label'       => esc_html__( 'Title', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => esc_html__( 'Text on the button', 'radiantthemes-addons' ),
			]
		);

		$this->add_control(
			'radiant_custom_btn_link',
			[
				'label'         => esc_html__( 'URL (Link)', 'radiantthemes-addons' ),
				'type'          => Controls_Manager::URL,
				'show_external' => true,
				'default'       => [
					'url'         => '',
					'is_external' => true,
					'nofollow'    => true,
				],
				'description'   => esc_html__( 'Add link to button.', 'radiantthemes-addons' ),
			]
		);

		$this->add_control(
			'radiant_custom_btn_alignment',
			[
				'label'       => esc_html__( 'Alignment', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::CHOOSE,
				'options'     => [
					'inline' => [
						'title' => esc_html__( 'Inline', 'radiantthemes-addons' ),
						'icon'  => 'fa fa-align-justify',
					],
					'left'   => [
						'title' => esc_html__( 'Left', 'radiantthemes-addons' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'radiantthemes-addons' ),
						'icon'  => 'fa fa-align-center',
					],
					'right'  => [
						'title' => esc_html__( 'Right', 'radiantthemes-addons' ),
						'icon'  => 'fa fa-align-right',
					],
				],
				'toggle'      => true,
				'description' => esc_html__( 'Select button alignment.', 'radiantthemes-addons' ),
				'condition' => [
					'radiant_custom_btn_style' => 'one',
				],
			]
		);

		$this->add_control(
			'radiant_custom_btn_block',
			[
				'label'        => esc_html__( 'Set full width button?', 'radiantthemes-addons' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'your-plugin' ),
				'label_off'    => esc_html__( 'No', 'your-plugin' ),
				'return_value' => 'yes',
				'default'      => 'yes',
				'condition'    => [
					'radiant_custom_btn_alignment' => 'inline',
				],
			]
		);

		$this->add_control(
			'radiant_custom_btn_add_icon',
			[
				'label'        => esc_html__( 'Add icon?', 'radiantthemes-addons' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'your-plugin' ),
				'label_off'    => esc_html__( 'No', 'your-plugin' ),
				'return_value' => 'yes',
				'default'      => 'yes',
				'condition' => [
					'radiant_custom_btn_style' => 'one',
				],
			]
		);

		$this->add_control(
			'radiant_custom_btn_icon_alignment',
			[
				'label'       => esc_html__( 'Icon Alignment', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT2,
				'options'     => [
					'left'  => esc_html__( 'Left', 'radiantthemes-addons' ),
					'right' => esc_html__( 'Right', 'radiantthemes-addons' ),
				],
				'condition'   => [
					'radiant_custom_btn_add_icon' => 'yes',
					'radiant_custom_btn_style' => 'one',
				],
				'description' => esc_html__( 'Select icon alignment.', 'radiantthemes-addons' ),
			]
		);

		$this->add_control(
			'radiant_custom_btn_icon',
			[
				'label'     => esc_html__( 'Icons', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::ICON,
				'condition' => [
					'radiant_custom_btn_add_icon' => 'yes',
					'radiant_custom_btn_style' => 'one',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style_custom_button_general',
			[
				'label' => esc_html__( 'General', 'radiantthemes-addons' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'content_typography',
				'label'    => esc_html__( 'Typography', 'radiantthemes-addons' ),
				'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .radiantthemes-custom-button .radiantthemes-custom-button-main > .placeholder, 
				               {{WRAPPER}} .radiantthemes-custom-button.element-two.hover-style-eight .radiant_btn a',
			]
		);

		$this->add_control(
			'radiant_custom_btn_color',
			[
				'label'       => esc_html__( 'Button Title Color', 'radiantthemes-addons' ),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .radiantthemes-custom-button .radiantthemes-custom-button-main' => 'color: {{VALUE}}',
					'{{WRAPPER}} .radiantthemes-custom-button.element-two.hover-style-eight .radiant_btn a' => 'color: {{VALUE}}',
					],
				'description' => esc_html__( 'Select Button Text color.', 'radiantthemes-addons' ),
			]
		);

		$this->add_control(
			'radiant_custom_btn_entrance_animation',
			[
				'label'        => esc_html__( 'Entrance Animation', 'radiantthemes-addons' ),
				'type'         => Controls_Manager::ANIMATION,
				'prefix_class' => 'animated ',
				'condition'   => [
					'radiant_custom_btn_style' => 'one',
				],
			]


		);

		$this->add_control(
			'radiant_custom_btn_hover_animation',
			[
				'label'        => esc_html__( 'Hover Animation', 'radiantthemes-addons' ),
				'type'         => Controls_Manager::HOVER_ANIMATION,
				'prefix_class' => 'elementor-animation-',
				'condition'   => [
					'radiant_custom_btn_style' => 'one',
				],
			]
		);

		$this->add_control(
			'radiant_custom_btn_gradient_bg_add',
			[
				'label'        => esc_html__( 'Add Gradient Background?', 'radiantthemes-addons' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'your-plugin' ),
				'label_off'    => esc_html__( 'No', 'your-plugin' ),
				'return_value' => 'yes',
				'default'      => 'yes',
				'description'  => esc_html__( 'Please Note: If selected, please do not use any background image or direct backgrund color.', 'radiantthemes-addons' ),
				'condition'   => [
					'radiant_custom_btn_style' => 'one',
				],
			]
		);

		$this->add_control(
			'radiant_custom_btn_gradient_bg_type',
			[
				'label'       => esc_html__( 'Gradient Background Type', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT2,
				'options'     => [
					'to bottom'       => esc_html__( 'To Bottom', 'radiantthemes-addons' ),
					'to top'          => esc_html__( 'To Top', 'radiantthemes-addons' ),
					'to right'        => esc_html__( 'To Right', 'radiantthemes-addons' ),
					'to left'         => esc_html__( 'To Left', 'radiantthemes-addons' ),
					'to top left'     => esc_html__( 'To Top Left', 'radiantthemes-addons' ),
					'to bottom left'  => esc_html__( 'To Bottom Left', 'radiantthemes-addons' ),
					'to top right'    => esc_html__( 'To Top Right', 'radiantthemes-addons' ),
					'to bottom right' => esc_html__( 'To Bottom Right', 'radiantthemes-addons' ),
				],
				'condition'   => [
					'radiant_custom_btn_gradient_bg_add' => 'yes',
					'radiant_custom_btn_style' => 'one',
				],
				'description' => esc_html__( 'Select backgroud type.', 'radiantthemes-addons' ),
			]
		);

		$this->add_control(
			'radiant_custom_btn_gradient_bg_color_one',
			[
				'label'     => esc_html__( 'Background Color (One)', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => [
					'radiant_custom_btn_gradient_bg_add' => 'yes',
					'radiant_custom_btn_style' => 'one',
				],
			]
		);

		$this->add_control(
			'radiant_custom_btn_gradient_bg_color_two',
			[
				'label'     => esc_html__( 'Background Color (Two)', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .radiantthemes-custom-button .radiantthemes-custom-button-main' => 'background: linear-gradient({{radiant_custom_btn_gradient_bg_type.VALUE}}, {{radiant_custom_btn_gradient_bg_color_one.VALUE}} 0%, {{VALUE}} 100%)',
				],
				'condition' => [
					'radiant_custom_btn_gradient_bg_add' => 'yes',
					'radiant_custom_btn_style' => 'one',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'border',
				'label'    => esc_html__( 'Border', 'radiantthemes-addons' ),
				'selector' => '{{WRAPPER}} .radiantthemes-custom-button .radiantthemes-custom-button-main',
				'condition'   => [
					'radiant_custom_btn_style' => 'one',
				],
			]

		);

		$this->add_control(
			'radiant_custom_btn_border_radius',
			[
				'label'      => esc_html__( 'Border Radius', 'radiantthemes-addons' ),
				'type'       => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range'      => [
					'px' => [
						'min' => 0,
						'max' => 35,
					],
				],
				'selectors'  => [
					'{{WRAPPER}} .radiantthemes-custom-button .radiantthemes-custom-button-main' => 'border-radius: {{SIZE}}{{UNIT}};',
				],
				'condition'   => [
					'radiant_custom_btn_style' => 'one',
				],
			]
		);

		$this->add_control(
			'radiant_custom_btn_bg_color',
			[
				'label'     => esc_html__( 'Background Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .radiantthemes-custom-button .radiantthemes-custom-button-main' => 'background-color: {{VALUE}}',
				],
				'condition' => [
					'radiant_custom_btn_gradient_bg_add!' => 'yes',
					'radiant_custom_btn_style' => 'one',
				],
			]
		);

		$this->add_control(
			'radiant_custom_btn_margin',
			[
				'label'      => esc_html__( 'Margin', 'radiantthemes-addons' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .radiantthemes-custom-button .radiantthemes-custom-button-main' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition'   => [
					'radiant_custom_btn_style' => 'one',
				],
			]
		);

		$this->add_control(
			'radiant_custom_btn_padding',
			[
				'label'      => esc_html__( 'Padding', 'radiantthemes-addons' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .radiantthemes-custom-button .radiantthemes-custom-button-main' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition'   => [
					'radiant_custom_btn_style' => 'one',
				],
			]
		);

		$this->add_control(
			'radiant_custom_btn_border_color',
			[
				'label'     => esc_html__( 'Border Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .radiant_btn::before' => 'border: 2px solid {{VALUE}}',
				],
				'condition'   => [
					'radiant_custom_btn_style' => 'two',
				],  
				
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style_custom_button_hover',
			[
				'label' => esc_html__( 'Hover Style', 'radiantthemes-addons' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'radiant_custom_btn_hover_style',
			[
				'label'       => esc_html__( 'Hover Style', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT2,
				'options'     => [
					'one'   => esc_html__( 'Style One', 'radiantthemes-addons' ),
					'two'   => esc_html__( 'Style Two', 'radiantthemes-addons' ),
					'three' => esc_html__( 'Style Three', 'radiantthemes-addons' ),
					'four'  => esc_html__( 'Style Four', 'radiantthemes-addons' ),
					'five'  => esc_html__( 'Style Five', 'radiantthemes-addons' ),
					'six'   => esc_html__( 'Style Six', 'radiantthemes-addons' ),
					'seven' => esc_html__( 'Style Seven', 'radiantthemes-addons' ),
				],
				'condition'   => [
					'radiant_custom_btn_style' => 'one',
				], 
				'default'     => 'one',
				'description' => esc_html__( 'Select hover style.', 'radiantthemes-addons' ),
			]
		);

		$this->add_control(
			'radiant_custom_btn_hover_gradient_bg_add',
			[
				'label'        => esc_html__( 'Add Hover Gradient Background?', 'radiantthemes-addons' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'your-plugin' ),
				'label_off'    => esc_html__( 'No', 'your-plugin' ),
				'return_value' => 'yes',
				'default'      => 'yes',
				'description'  => esc_html__( 'Please Note: If selected, please do not use any background image or direct backgrund color.', 'radiantthemes-addons' ),
				'condition'   => [
					'radiant_custom_btn_style' => 'one',
				],
			]
		);

		$this->add_control(
			'radiant_custom_btn_hover_gradient_bg_type',
			[
				'label'       => esc_html__( 'Hover Gradient Background Type', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT2,
				'options'     => [
					'to bottom'       => esc_html__( 'To Bottom', 'radiantthemes-addons' ),
					'to top'          => esc_html__( 'To Top', 'radiantthemes-addons' ),
					'to right'        => esc_html__( 'To Right', 'radiantthemes-addons' ),
					'to left'         => esc_html__( 'To Left', 'radiantthemes-addons' ),
					'to top left'     => esc_html__( 'To Top Left', 'radiantthemes-addons' ),
					'to bottom left'  => esc_html__( 'To Bottom Left', 'radiantthemes-addons' ),
					'to top right'    => esc_html__( 'To Top Right', 'radiantthemes-addons' ),
					'to bottom right' => esc_html__( 'To Bottom Right', 'radiantthemes-addons' ),
				],
				'condition'   => [
					'radiant_custom_btn_hover_gradient_bg_add' => 'yes',
					'radiant_custom_btn_style' => 'one',
				],
				'description' => esc_html__( 'Select backgroud type.', 'radiantthemes-addons' ),
			]
		);

		$this->add_control(
			'radiant_custom_btn_hover_gradient_bg_color_one',
			[
				'label'     => esc_html__( 'Hover Background Color (One)', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => [
					'radiant_custom_btn_hover_gradient_bg_add' => 'yes',
					'radiant_custom_btn_style' => 'one',
				],
			]
		);

		$this->add_control(
			'radiant_custom_btn_hover_gradient_bg_color_two',
			[
				'label'     => esc_html__( 'Hover Background Color (Two)', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .radiantthemes-custom-button-main:hover' => 'background: linear-gradient({{radiant_custom_btn_hover_gradient_bg_type.VALUE}}, {{radiant_custom_btn_hover_gradient_bg_color_one.VALUE}} 0%, {{VALUE}} 100%)',
				],
				'condition' => [
					'radiant_custom_btn_hover_gradient_bg_add' => 'yes',
					'radiant_custom_btn_style' => 'one',
				],
			]
		);

		$this->add_control(
			'radiant_custom_btn_bg_hover_color',
			[
				'label'     => esc_html__( 'Background Hover Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .radiantthemes-custom-button-main:hover' => 'background-color: {{VALUE}}',
				],
				'condition'   => [
					'radiant_custom_btn_style' => 'one',
					'radiant_custom_btn_hover_gradient_bg_add!' => 'yes',
				],  

			]
		);


		$this->add_control(
			'radiant_custom_btn_border_hover_color',
			[
				'label'     => esc_html__( 'Border Hover Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .radiantthemes-custom-button-main:hover' => 'border: {{VALUE}}',
					'{{WRAPPER}} .radiant_btn:hover::before' => 'border: {{VALUE}}',
					
				],
			]
		);

		$this->add_control(
			'radiant_custom_btn_font_hover_color',
			[
				'label'     => esc_html__( 'Font Hover Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .radiantthemes-custom-button-main:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} .radiantthemes-custom-button.element-two.hover-style-eight .radiant_btn:hover a' => 'color: {{VALUE}}',
					
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'hover_border',
				'label'    => esc_html__( 'Border Hover', 'radiantthemes-addons' ),
				'selector' => '{{WRAPPER}} .radiantthemes-custom-button .radiantthemes-custom-button-main:hover',
				'condition'   => [
					'radiant_custom_btn_gradient_bg_add!' => 'yes',
				],
			]

		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		if ( 'two' === $settings['radiant_custom_btn_style'] ) {
			$target   = $settings['radiant_custom_btn_link']['is_external'] ? ' target="_blank"' : '';
		   $nofollow = $settings['radiant_custom_btn_link']['nofollow'] ? ' rel="nofollow"' : '';
		   
			$output  = '<div class="radiantthemes-custom-button element-two hover-style-eight">';
			$output  .= '<div class="radiant_area radiant_btn">';

			if ( strlen( $settings['radiant_custom_btn_link']['url'] ) > 0 ) {
			$output .= '<a href="' . esc_url( $settings['radiant_custom_btn_link']['url'] ) . '" ' . $target . $nofollow . ' >';
			}
			$output .= $settings['radiant_custom_btn_title'];
			if ( strlen( $settings['radiant_custom_btn_link']['url'] ) > 0 ) {
						$output .= '</a>';
		    }

        		$output  .= '</div>';
    		$output  .= '</div>';
			echo $output;
		} else {	

		$target   = $settings['radiant_custom_btn_link']['is_external'] ? ' target="_blank"' : '';
		$nofollow = $settings['radiant_custom_btn_link']['nofollow'] ? ' rel="nofollow"' : '';

		if ( ! empty( $settings['radiant_custom_btn_bg_hover_color'] ) || ! empty( $settings['radiant_custom_btn_border_hover_color'] ) || ! empty( $settings['radiant_custom_btn_font_hover_color'] ) ) {

			// HOVER STYLE ONE.
			if ( 'one' === $settings['radiant_custom_btn_hover_style'] ) {

				$style  = '.radiantthemes-custom-button .radiantthemes-custom-button-main:hover {';
				$style .= ( ! empty( $settings['radiant_custom_btn_bg_hover_color'] ) ) ? ' background-color:' . $settings['radiant_custom_btn_bg_hover_color'] . ' !important;' : '';
				$style .= ( ! empty( $settings['radiant_custom_btn_border_hover_color'] ) ) ? ' border-top-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important; border-right-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important; border-bottom-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important; border-left-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important;' : '';
				$style .= ( ! empty( $settings['radiant_custom_btn_font_hover_color'] ) ) ? ' color:' . $settings['radiant_custom_btn_font_hover_color'] . ' !important;' : '';
				$style .= '}';
				wp_add_inline_style( 'radiantthemes-addons-custom', $style );

			} elseif ( 'two' === $settings['radiant_custom_btn_hover_style'] ) { // HOVER STYLE TWO.

				$style  = '.radiantthemes-custom-button .radiantthemes-custom-button-main:hover {';
				$style .= ( ! empty( $settings['radiant_custom_btn_border_hover_color'] ) ) ? ' border-top-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important;border-bottom-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important; border-left-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important; border-right-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important;' : '';
				$style .= ( ! empty( $settings['radiant_custom_btn_font_hover_color'] ) ) ? ' color:' . $settings['radiant_custom_btn_font_hover_color'] . ' !important;' : '';
				$style .= '}';
				$style .= '.radiantthemes-custom-button.hover-style-two .radiantthemes-custom-button-main > .overlay {';
				$style .= ( ! empty( $settings['radiant_custom_btn_bg_hover_color'] ) ) ? ' background-color:' . $settings['radiant_custom_btn_bg_hover_color'] .  ' !important;' : '';
				$style .= '}';
				wp_add_inline_style( 'radiantthemes-addons-custom', $style );

			} elseif ( 'three' === $settings['radiant_custom_btn_hover_style'] ) { // HOVER STYLE THREE.

				$style  = '.radiantthemes-custom-button .radiantthemes-custom-button-main:hover {';
				$style .= ( ! empty( $settings['radiant_custom_btn_border_hover_color'] ) ) ? ' border-top-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important;border-bottom-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important; border-left-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important; border-right-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important;' : '';
				$style .= ( ! empty( $settings['radiant_custom_btn_font_hover_color'] ) ) ? ' color:' . $settings['radiant_custom_btn_font_hover_color'] . ' !important;' : '';
				$style .= '}';
				$style .= '.radiantthemes-custom-button.hover-style-three .radiantthemes-custom-button-main > .overlay {';
				$style .= ( ! empty( $settings['radiant_custom_btn_bg_hover_color'] ) ) ? ' background-color:' . $settings['radiant_custom_btn_bg_hover_color'] . ';' : '';
				$style .= '}';
				wp_add_inline_style( 'radiantthemes-addons-custom', $style );

			} elseif ( 'four' === $settings['radiant_custom_btn_hover_style'] ) { // HOVER STYLE FOUR.

				$style  = '.radiantthemes-custom-button .radiantthemes-custom-button-main:hover{';
				$style .= ( ! empty( $settings['radiant_custom_btn_bg_hover_color'] ) ) ? ' background-color:' . $settings['radiant_custom_btn_bg_hover_color'] . ' !important;' : '';
				$style .= ( ! empty( $settings['radiant_custom_btn_border_hover_color'] ) ) ? ' border-top-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important;border-bottom-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important; border-left-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important; border-right-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important;' : '';
				$style .= ( ! empty( $settings['radiant_custom_btn_font_hover_color'] ) ) ? ' color:' . $settings['radiant_custom_btn_font_hover_color'] . ' !important;' : '';
				$style .= '}';
				wp_add_inline_style( 'radiantthemes-addons-custom', $style );

			} elseif ( 'five' === $settings['radiant_custom_btn_hover_style'] ) { // HOVER STYLE FIVE.

				$style  = '.radiantthemes-custom-button .radiantthemes-custom-button-main:hover {';
				$style .= ( ! empty( $settings['radiant_custom_btn_bg_hover_color'] ) ) ? ' background-color:' . $settings['radiant_custom_btn_bg_hover_color'] . ' !important;' : '';
				$style .= ( ! empty( $settings['radiant_custom_btn_border_hover_color'] ) ) ? ' border-top-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important; border-right-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important; border-bottom-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important; border-left-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important;' : '';
				$style .= ( ! empty( $settings['radiant_custom_btn_font_hover_color'] ) ) ? ' color:' . $settings['radiant_custom_btn_font_hover_color'] . ' !important;' : '';
				$style .= '}';
				wp_add_inline_style( 'radiantthemes-addons-custom', $style );

			} elseif ( 'six' === $settings['radiant_custom_btn_hover_style'] ) { // HOVER STYLE SIX.

				$style  = '.radiantthemes-custom-button .radiantthemes-custom-button-main:hover {';
				$style .= ( ! empty( $settings['radiant_custom_btn_bg_hover_color'] ) ) ? ' background-color:' . $settings['radiant_custom_btn_bg_hover_color'] . ' !important;' : '';
				$style .= ( ! empty( $settings['radiant_custom_btn_border_hover_color'] ) ) ? ' border-top-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important; border-right-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important; border-bottom-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important; border-left-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important;' : '';
				$style .= ( ! empty( $settings['radiant_custom_btn_font_hover_color'] ) ) ? ' color:' . $settings['radiant_custom_btn_font_hover_color'] . ' !important;' : '';
				$style .= '}';
				wp_add_inline_style( 'radiantthemes-addons-custom', $style );

			} elseif ( 'seven' === $settings['radiant_custom_btn_hover_style'] ) { // HOVER STYLE SEVEN.

				$style  = '.radiantthemes-custom-button .radiantthemes-custom-button-main:hover {';
				$style .= ( ! empty( $settings['radiant_custom_btn_bg_hover_color'] ) ) ? ' background-color:' . $settings['radiant_custom_btn_bg_hover_color'] . ' !important;' : '';
				$style .= ( ! empty( $settings['radiant_custom_btn_border_hover_color'] ) ) ? ' border-top-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important; border-right-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important; border-bottom-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important; border-left-color:' . $settings['radiant_custom_btn_border_hover_color'] . ' !important;' : '';
				$style .= ( ! empty( $settings['radiant_custom_btn_font_hover_color'] ) ) ? ' color:' . $settings['radiant_custom_btn_font_hover_color'] . ' !important;' : '';
				$style .= '}';
				wp_add_inline_style( 'radiantthemes-addons-custom', $style );

			}
		}

		$output  = '<div class="radiantthemes-custom-button element-' . esc_attr( $settings['radiant_custom_btn_style'] ) . ' hover-style-' . esc_attr( $settings['radiant_custom_btn_hover_style'] ) . ' ' . $settings['radiant_custom_btn_entrance_animation'] . ' ' . $settings['radiant_custom_btn_hover_animation'] . '" data-button-direction="' . $settings['radiant_custom_btn_alignment'] . '"';
		$output .= ' data-button-fullwidth=';

		$output .= ( $settings['radiant_custom_btn_block'] ) ? '"true" ' : '"false" ';
		if ( $settings['radiant_custom_btn_add_icon'] ) {
			$output .= ' data-button-icon-position="' . $settings['radiant_custom_btn_icon_alignment'] . '"';
		}
		$output .= '>';

		if ( strlen( $settings['radiant_custom_btn_link']['url'] ) > 0 ) {
			$output .= '<a class="radiantthemes-custom-button-main" href="' . esc_url( $settings['radiant_custom_btn_link']['url'] ) . '" ' . $target . $nofollow . ' >';
			// HOVER STYLE ONE.
			if ( 'one' === $settings['radiant_custom_btn_hover_style'] ) { // NO OVERLAY.
				$output .= '';
			} elseif ( 'two' === $settings['radiant_custom_btn_hover_style'] ) { // HOVER STYLE TWO.
				$output .= '<div class="overlay" style="background-color:' . $settings['radiant_custom_btn_bg_hover_color'].';"></div>';
			} elseif ( 'three' === $settings['radiant_custom_btn_hover_style'] ) { // HOVER STYLE THREE.
				$output .= '<div class="overlay"></div>';
			} elseif ( 'four' === $settings['radiant_custom_btn_hover_style'] ) { // HOVER STYLE FOUR.
				$output .= '';
			}
			$output .= '<div class="placeholder">';
		}

		if ( ! empty( $settings['radiant_custom_btn_add_icon'] ) && 'left' === $settings['radiant_custom_btn_icon_alignment'] ) {
			$output .= '<i class="' . $settings['radiant_custom_btn_icon'] . '"></i>';
		}
		$output .= $settings['radiant_custom_btn_title'];
		if ( ! empty( $settings['radiant_custom_btn_add_icon'] ) && 'right' === $settings['radiant_custom_btn_icon_alignment'] ) {
			$output .= '<i class="' . $settings['radiant_custom_btn_icon'] . '"></i>';
		}

		if ( strlen( $settings['radiant_custom_btn_link']['url'] ) > 0 ) {
			$output .= '</div>';
			$output .= '</a>';
		}

		$output .= '</div>';

		echo $output;
	}

}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function _content_template() {

	}
}
