<?php
/**
 * Testimonial Style Addon
 *
 * @package Radiantthemes
 */

namespace RadiantthemesAddons\Widgets;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Widget_Base;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor Testimonial widget.
 *
 * Elementor widget that displays Testimonials in different styles.
 *
 * @since 1.0.0
 */
class Radiantthemes_Style_Testimonial extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'radiant-testimonial';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Testimonial', 'radiantthemes-addons' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-testimonial';
	}

	/**
	 * Requires css files.
	 *
	 * @return array
	 */
	public function get_style_depends() {
		return [
			'radiantthemes-addons-custom',
		];
	}

	/**
	 * Requires js files.
	 *
	 * @return array
	 */
	public function get_script_depends() {
		return [
			'radiantthemes-testimonial',
		];
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.1.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'radiant-widgets-category' ];
	}

	/**
	 * Get all Testimonial Custom Post Type Categories.
	 *
	 * @return array Testimonial categories.
	 */
	public function get_testimonial_categories() {
		$testimonial_terms = get_terms(
			array(
				'taxonomy'   => 'testimonial-category',
				'hide_empty' => false,
			)
		);

		$testimonial_category_array = array();
		$testimonial_category_array = array( 'all' => 'Show all categories' );
		if ( ! empty( $testimonial_terms ) ) {
			foreach ( $testimonial_terms as $testimonial_term ) {
				$testimonial_category_array[ $testimonial_term->slug ] = $testimonial_term->name;
			}
		}

		return $testimonial_category_array;
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'section_content',
			[
				'label' => esc_html__( 'Content', 'radiantthemes-addons' ),
			]
		);

		$this->add_control(
			'testimonial_style',
			[
				'label'       => esc_html__( 'Testimonial Style', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT2,
				'options'     => [
					'one'   => esc_html__( 'Style One', 'radiantthemes-addons' ),
					'two'   => esc_html__( 'Style Two', 'radiantthemes-addons' ),
					'three' => esc_html__( 'Style Three', 'radiantthemes-addons' ),
					'four'  => esc_html__( 'Style Four', 'radiantthemes-addons' ),
					'five'  => esc_html__( 'Style Five', 'radiantthemes-addons' ),
					
				],
				'default'     => 'one',
			]
		);

		$this->add_control(
			'testimonial_category',
			[
				'label'       => esc_html__( 'Select Testimonial Category', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT2,
				'options'     => $this->get_testimonial_categories(),
				'default'     => 'all',
			]
		);

		$this->add_control(
			'testimonial_allow_carousel',
			[
				'label'   => esc_html__( 'Carousel', 'radiantthemes-addons' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'false' => esc_html__( 'No', 'radiantthemes-addons' ),
					'true'  => esc_html__( 'Yes', 'radiantthemes-addons' ),
				],
				'default' => 'true',
				'condition' => [
					'testimonial_style!' => 'five',
				],
			]
		);

		$this->add_control(
			'allow_nav',
			[
				'label'     => esc_html__( 'Allow Navigation?', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'false' => esc_html__( 'No', 'radiantthemes-addons' ),
					'true'  => esc_html__( 'Yes', 'radiantthemes-addons' ),
				],
				'default'   => 'true',
				'condition' => [
					'testimonial_allow_carousel' => 'true',
				],
			]
		);

		$this->add_control(
			'navigation_style',
			[
				'label'       => esc_html__( 'Navigation Style', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT2,
				'options'     => [
					'one'   => esc_html__( 'Style One (Arrow - Light)', 'radiantthemes-addons' ),
					'two'   => esc_html__( 'Style Two (Circle)', 'radiantthemes-addons' ),
					'three' => esc_html__( 'Style Three (Arrow - Dark)', 'radiantthemes-addons' ),
				],
				'default'     => 'one',
				'condition'   => [
					'allow_nav'                   => 'true',
					'testimonial_allow_carousel!' => 'false',
				],
			]
		);

		$this->add_control(
			'allow_dots',
			[
				'label'       => esc_html__( 'Allow Dots for Navigation?', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'options'     => [
					'false' => esc_html__( 'No', 'radiantthemes-addons' ),
					'true'  => esc_html__( 'Yes', 'radiantthemes-addons' ),
				],
				'default'     => 'true',
				'condition'   => [
					'testimonial_allow_carousel' => 'true',
				],
			]
		);

		$this->add_control(
			'navigation_dot_style',
			[
				'label'       => esc_html__( 'Navigation Dot Style', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT2,
				'options'     => [
					'one' => esc_html__( 'Center Dot (Dark)', 'radiantthemes-addons' ),
					'two' => esc_html__( 'Right Dot (Light)', 'radiantthemes-addons' ),
				],
				'default'     => 'two',
				'condition'   => [
					'allow_dots'                  => 'true',
					'testimonial_allow_carousel!' => 'false',
				],
			]
		);

		$this->add_control(
			'allow_loop',
			[
				'label'       => esc_html__( 'Allow Loop?', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'options'     => [
					'false' => esc_html__( 'No', 'radiantthemes-addons' ),
					'true'  => esc_html__( 'Yes', 'radiantthemes-addons' ),
				],
				'default'     => 'true',
				'condition'   => [
					'testimonial_allow_carousel' => 'true',
				],
			]
		);

		$this->add_control(
			'allow_autoplay',
			[
				'label'       => esc_html__( 'Allow Autoplay?', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT,
				'options'     => [
					'false' => esc_html__( 'No', 'radiantthemes-addons' ),
					'true'  => esc_html__( 'Yes', 'radiantthemes-addons' ),
				],
				'default'     => 'true',
				'condition'   => [
					'testimonial_allow_carousel' => 'true',
				],
			]
		);

		$this->add_control(
			'autoplay_timeout',
			[
				'label'       => esc_html__( 'Autoplay Timeout (in milliseconds)', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::NUMBER,
				'min'         => 500,
				'default'     => 6000,
				'step'        => 500,
				'condition'   => [
					'testimonial_allow_carousel' => 'true',
				],
			]
		);

		$this->add_control(
			'order',
			[
				'label'       => esc_html__( 'Order', 'radiantthemes-addons' ),
				'label_block' => false,
				'type'        => Controls_Manager::SELECT,
				'options'     => [
					'ASC'  => esc_html__( 'Ascending', 'radiantthemes-addons' ),
					'DESC' => esc_html__( 'Descending', 'radiantthemes-addons' ),
				],
				'default'     => 'DESC',
			]
		);

		$this->add_control(
			'order_by',
			[
				'label'       => esc_html__( 'Order By', 'radiantthemes-addons' ),
				'label_block' => true,
				'type'        => Controls_Manager::SELECT2,
				'options'     => [
					'date'     => esc_html__( 'Date', 'radiantthemes-addons' ),
					'title'    => esc_html__( 'Title', 'radiantthemes-addons' ),
					'ID'       => esc_html__( 'ID', 'radiantthemes-addons' ),
					'rand'     => esc_html__( 'Random', 'radiantthemes-addons' ),
					'modified' => esc_html__( 'Last Modified', 'radiantthemes-addons' ),
				],
				'default'     => 'date',
			]
		);

		$this->add_control(
			'max_posts',
			[
				'label'       => esc_html__( 'Count', 'radiantthemes-addons' ),
				'type'        => Controls_Manager::NUMBER,
				'min'         => -1,
				'description' => esc_html__( 'Number of posts to show ( -1 for all posts )', 'radiantthemes-addons' ),
				'default'     => 4,
			]
		);

		$this->add_control(
			'posts_in_desktop',
			[
				'label'       => esc_html__( 'Number of Posts on Desktop', 'radiantthemes-addons' ),
				'type'        => Controls_Manager::NUMBER,
				'description' => esc_html__( 'Posts on Desktop', 'radiantthemes-addons' ),
				'condition'   => [
					'testimonial_allow_carousel' => 'true',
				],
				'default'     => 2,
			]
		);

		$this->add_control(
			'posts_in_tab',
			[
				'label'       => esc_html__( 'Number of Posts on Tab', 'radiantthemes-addons' ),
				'type'        => Controls_Manager::NUMBER,
				'description' => esc_html__( 'Posts on Tab', 'radiantthemes-addons' ),
				'condition'   => [
					'testimonial_allow_carousel' => 'true',
				],
				'default'     => 2,
			]
		);

		$this->add_control(
			'posts_in_mobile',
			[
				'label'       => esc_html__( 'Number of Posts on Mobile', 'radiantthemes-addons' ),
				'type'        => Controls_Manager::NUMBER,
				'description' => esc_html__( 'Posts on Mobile', 'radiantthemes-addons' ),
				'condition'   => [
					'testimonial_allow_carousel' => 'true',
				],
				'default'     => 1,
			]
		);

		$this->add_control(
			'testimonial_no_row_items',
			[
				'label'       => esc_html__( 'Number of Row Items', 'radiantthemes-addons' ),
				'type'        => Controls_Manager::NUMBER,
				'description' => esc_html__( 'Select number of items you want to see in a row', 'radiantthemes-addons' ),
				'condition'   => [
					'testimonial_allow_carousel' => 'false',
				],
				'default'     => 2,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style_testimonial_general',
			[
				'label' => esc_html__( 'General', 'radiantthemes-addons' ),
				'tab'   => Controls_Manager::TAB_STYLE,
				'condition' => [
					'testimonial_style!' => 'five',
				],
			]
		);

		$this->add_control(
			'testimonial_color',
			[
				'label'     => esc_html__( 'Color Scheme', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'scheme'    => [
					'type'  => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_1,
				],
				'selectors' => [
					'{{WRAPPER}} .testimonial.element-one .testimonial-item > .holder > .testimonial-pic > .testimonial-pic-holder > .testimonial-pic-icon,
					.testimonial[class*="element-"].owl-nav-style-two .owl-nav > .owl-prev,
					.testimonial[class*="element-"].owl-nav-style-two .owl-nav > .owl-next,
					.testimonial[class*="element-"].owl-dot-style-one .owl-dots > .owl-dot.active > span,
					.testimonial[class*="element-"].owl-dot-style-two .owl-dots > .owl-dot > span' => 'background-color: {{VALUE}}',

					'{{WRAPPER}} .testimonial.element-seven .testimonial-item > .holder > .testimonial-main > .testimonial-title .title' => 'color: {{VALUE}}',

					'{{WRAPPER}} .testimonial.element-seven .testimonial-item > .holder:hover' => 'border-top-color: {{VALUE}}',

					'{{WRAPPER}} .testimonial-style6 .author p' => 'color: {{VALUE}}',
					'{{WRAPPER}} .element-four .quote_area .midd' => 'color: {{VALUE}}',
				],
				'default'   => '#000000',
				
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style_testimonial_content',
			[
				'label' => esc_html__( 'Content', 'radiantthemes-addons' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label'    => esc_html__( 'Content Typography', 'radiantthemes-addons' ),
				'name'     => 'content_typography',
				'selector' => '{{WRAPPER}} .element-five .testimonial-content, {{WRAPPER}} .testimonial .testimonial-item > .holder > .testimonial-data blockquote h5, {{WRAPPER}} .testimonial .testimonial-item > .holder > .testimonial-data blockquote p, {{WRAPPER}} .testimonial-style6 .description,{{WRAPPER}} .element-four.testimonial .testimonial-content,  {{WRAPPER}} .testimonial.element-two .testimonial-item > .holder > .testimonial-data blockquote span',
			]
		);

		$this->add_control(
			'testimonial_content_color',
			[
				'label'     => esc_html__( 'Content Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonial .testimonial-item > .holder > .testimonial-data blockquote h5' => 'color: {{VALUE}}',
					'{{WRAPPER}} .testimonial.element-two .testimonial-item > .holder > .testimonial-data blockquote span' => 'color: {{VALUE}}',
					'{{WRAPPER}} .testimonial .testimonial-item > .holder > .testimonial-data blockquote p' => 'color: {{VALUE}}',
					'{{WRAPPER}} .testimonial-style6 .description' => 'color: {{VALUE}}',
					'{{WRAPPER}} .element-four .testimonial-content' => 'color: {{VALUE}}',
					'{{WRAPPER}} .element-five .testimonial-content' => 'color: {{VALUE}}',

				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style_testimonial_title',
			[
				'label' => esc_html__( 'Title', 'radiantthemes-addons' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label'    => esc_html__( 'Title Typography', 'radiantthemes-addons' ),
				'name'     => 'title_typography',
				'selector' => '{{WRAPPER}} .testimonial-style6 .author h5, {{WRAPPER}} .element-five .testimonial-name h4, {{WRAPPER}} .testimonial .testimonial-item > .holder > .testimonial-title .title, {{WRAPPER}} .testimonial.element-two .testimonial-item > .holder > .testimonial-title > .testimonial-title-data .title, {{WRAPPER}} .element-four .testimonial-name',
			]
		);

		$this->add_control(
			'testimonial_title_color',
			[
				'label'     => esc_html__( 'Title Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonial .testimonial-item > .holder > .testimonial-title .title' => 'color: {{VALUE}}',

					'{{WRAPPER}} .testimonial.element-two .testimonial-item > .holder > .testimonial-title > .testimonial-title-data .title' => 'color: {{VALUE}}',
					'{{WRAPPER}} .element-four .testimonial-name' => 'color: {{VALUE}}',
					'{{WRAPPER}} .element-five .testimonial-name h4' => 'color: {{VALUE}}',
					'{{WRAPPER}} .testimonial-style6 .author h5' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style_testimonial_designation',
			[
				'label' => esc_html__( 'Designation', 'radiantthemes-addons' ),
				'tab'   => Controls_Manager::TAB_STYLE,
				'condition' => [
					'testimonial_style!' => 'five',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label'    => esc_html__( 'Designation Typography', 'radiantthemes-addons' ),
				'name'     => 'designation_typography',
				'selector' => '{{WRAPPER}} .testimonial-style6 .author p ,{{WRAPPER}} .testimonial .testimonial-item > .holder > .testimonial-title .designation, {{WRAPPER}} .testimonial.element-two .testimonial-item > .holder > .testimonial-title > .testimonial-title-data .designation, {{WRAPPER}} .element-four .testimonial-job',
				'condition' => [
					'testimonial_style!' => 'five',
				],
			]
		);

		$this->add_control(
			'testimonial_desig_color',
			[
				'label'     => esc_html__( 'Designation Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonial .testimonial-item > .holder > .testimonial-title .designation' => 'color: {{VALUE}}',

					'{{WRAPPER}} .testimonial.element-two .testimonial-item > .holder > .testimonial-title > .testimonial-title-data .designation' => 'color: {{VALUE}}',
					'{{WRAPPER}} .element-four .testimonial-job' => 'color: {{VALUE}}',
					'{{WRAPPER}} .testimonial-style6 .author p' => 'color: {{VALUE}}',
				],
				'condition' => [
					'testimonial_style!' => 'five',
				],
			]
		);
        $this->end_controls_section();
        
		$this->start_controls_section(
			'section_style_testimonial_next',
			[
				'label' => esc_html__( 'Next Prev', 'radiantthemes-addons' ),
				'tab'   => Controls_Manager::TAB_STYLE,
				'condition' => [
					'testimonial_style' => 'five',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'label'    => esc_html__( 'Next Prev Typography', 'radiantthemes-addons' ),
				'name'     => 'next_typography',
				'selector' => '{{WRAPPER}} .testimonial.owl-nav-style-one .owl-nav > .owl-next, {{WRAPPER}} .testimonial.owl-nav-style-one .owl-nav > .owl-prev',
				'condition' => [
					'testimonial_style' => 'five',
				],
			]
		);

		$this->add_control(
			'testimonial_next_color',
			[
				'label'     => esc_html__( 'Next Prev Color', 'radiantthemes-addons' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .testimonial.owl-nav-style-one .owl-nav > .owl-next' => 'color: {{VALUE}}',
					'{{WRAPPER}} .testimonial.owl-nav-style-one .owl-nav > .owl-prev' => 'color: {{VALUE}}',
				],
				'condition' => [
					'testimonial_style' => 'five',
				],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		$navigation_style = $settings['allow_nav'] ? 'owl-nav-style-' . esc_attr( $settings['navigation_style'] ) : '';
		$dot_style        = $settings['allow_dots'] ? 'owl-dot-style-' . esc_attr( $settings['navigation_dot_style'] ) : '';

		$testimonial_id   = ( 'three' === $settings['testimonial_style'] ) ? ' id="testimonial-slider-three"' : '';
		$testimonial_five = ( 'five' === $settings['testimonial_style'] ) ? 'testimonial rt-testimonial' : ' testimonial';

		if ( 'false' === $settings['testimonial_allow_carousel'] ) {

			$output = '<div class="element-' . esc_attr( $settings['testimonial_style'] ) . ' ' . $testimonial_five . '"  data-row-items="' . esc_attr( $settings['testimonial_no_row_items'] ) . '">';

		} elseif ( 'true' === $settings['testimonial_allow_carousel'] || 'five' == $settings['testimonial_style'] ) {
			$testimonial_five = ( 'five' === $settings['testimonial_style'] ) ? ' rt-testimonial owl-carousel' : ' testimonial owl-carousel';
			$center           = ( 'five' === $settings['testimonial_style'] ) ? ' data-owl-center="true"' : ' data-owl-center="false"';
			$output           = '<div class="element-' . esc_attr( $settings['testimonial_style'] ) . ' ' . $navigation_style . ' ' . $dot_style . ' ' . $testimonial_five . '"' . $testimonial_id . ' data-owl-nav="' . esc_attr( $settings['allow_nav'] ) . '" data-owl-dots="' . esc_attr( $settings['allow_dots'] ) . '" data-owl-loop="' . esc_attr( $settings['allow_loop'] ) . '" data-owl-autoplay="' . esc_attr( $settings['allow_autoplay'] ) . '" data-owl-autoplay-timeout="' . esc_attr( $settings['autoplay_timeout'] ) . '" data-owl-mobile-items="' . esc_attr( $settings['posts_in_mobile'] ) . '" data-owl-tab-items="' . esc_attr( $settings['posts_in_tab'] ) . '" data-owl-desktop-items="' . esc_attr( $settings['posts_in_desktop'] ) . '"  data-slider-id="1" ' . $center . '>';

		} else {
			$output = '';
		}

		if ( 'all' === $settings['testimonial_category'] ) {
			$testimonial_category = '';
		} else {
			$testimonial_category = array(
				array(
					'taxonomy' => 'testimonial-category',
					'field'    => 'slug',
					'terms'    => esc_attr( $settings['testimonial_category'] ),
				),
			);
		}

		if ( empty( $settings['max_posts'] ) ) {
			$settings['max_posts'] = -1;
		}

		$query = new \WP_Query(
			array(
				'post_type'      => 'testimonial',
				'posts_per_page' => $settings['max_posts'],
				'order'          => $settings['order'],
				'orderby'        => $settings['order_by'],
				'tax_query'      => $testimonial_category,
			)
		);

		if ( $query->have_posts() ) {
			while ( $query->have_posts() ) {
				$query->the_post();
				if ('five' == $settings['testimonial_style']) {
					require 'template/template-testimonial-element-' . $settings['testimonial_style'] . '.php';
				} else {

						if ( 'three' !== $settings['testimonial_style'] && 'five' !== $settings['testimonial_style'] ) {
							if ( ! has_post_thumbnail() ) {
								$output .= '<div class="testimonial-item no-image">';
							} else {
								$output .= '<div class="testimonial-item">';
							}
						}

						require 'template/template-testimonial-element-' . $settings['testimonial_style'] . '.php';

						if ( 'three' !== $settings['testimonial_style'] && 'five' !== $settings['testimonial_style'] ) {
							$output .= '</div>';
						}

				}


					


			}
			wp_reset_postdata();
		} else {
			echo '<p>No items found</p>';
		}

		$output .= '</div>';

		echo $output;
		?>
		<?php
	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.1.0
	 *
	 * @access protected
	 */
	protected function _content_template() {

	}
}
